Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS CodeConnections.

Actions, resources, and condition keys for AWS CodeConnections - Service Authorization Reference

# Actions, resources, and condition keys for AWS CodeConnections

AWS CodeConnections (service prefix: `codeconnections` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS CodeConnections
- Resource types defined by AWS CodeConnections
- Condition keys for AWS CodeConnections

## Actions defined by AWS CodeConnections

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateConnection | Grants permission to create a Connection resource | Write |  | aws:RequestTag/${TagKey} aws:TagKeys codeconnections:ProviderType |
CreateHost | Grants permission to create a host resource | Write |  | aws:RequestTag/${TagKey} aws:TagKeys codeconnections:ProviderType |
CreateRepositoryLink | Grants permission to create a repository link | Write | Connection* |  | codeconnections:PassConnection codeconnections:UseConnection
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateSyncConfiguration | Grants permission to create a template sync config | Write | RepositoryLink* |  | codeconnections:PassRepository iam:PassRole
| codeconnections:Branch |
DeleteConnection | Grants permission to delete a Connection resource | Write | Connection* |  |
DeleteHost | Grants permission to delete a host resource | Write | Host* |  |
DeleteRepositoryLink | Grants permission to delete a repository link | Write | RepositoryLink* |  |
DeleteSyncConfiguration | Grants permission to delete a sync configuration | Write |  |  |
GetConnection | Grants permission to get details about a Connection resource | Read | Connection* |  |
GetHost | Grants permission to get details about a host resource | Read | Host* |  |
GetIndividualAccessToken [permission only] | Grants permission to associate a third party, such as a Bitbucket App installation, with a Connection | Read |  | codeconnections:ProviderType | codeconnections:StartOAuthHandshake
GetInstallationUrl [permission only] | Grants permission to associate a third party, such as a Bitbucket App installation, with a Connection | Read |  | codeconnections:ProviderType |
GetRepositoryLink | Grants permission to describe a repository link | Read | RepositoryLink* |  |
GetRepositorySyncStatus | Grants permission to get the latest sync status for a repository | Read | RepositoryLink* |  |
| codeconnections:Branch |
GetResourceSyncStatus | Grants permission to get the latest sync status for a resource (cfn stack or other resources) | Read |  |  |
GetSyncBlockerSummary | Grants permission to describe service sync blockers on a resource (cfn stack or other resources) | Read |  |  |
GetSyncConfiguration | Grants permission to describe a sync configuration | Read |  |  |
ListConnections | Grants permission to list Connection resources | List | Connection* |  |
| codeconnections:ProviderTypeFilter |
ListHosts | Grants permission to list host resources | List |  | codeconnections:ProviderTypeFilter |
ListInstallationTargets [permission only] | Grants permission to associate a third party, such as a Bitbucket App installation, with a Connection | List |  |  | codeconnections:GetIndividualAccessToken codeconnections:StartOAuthHandshake
ListRepositoryLinks | Grants permission to list repository links | List |  |  |
ListRepositorySyncDefinitions | Grants permission to list repository sync definitions | List |  |  |
ListSyncConfigurations | Grants permission to list sync configurations for a repository link | List |  |  |
ListTagsForResource | Grants permission to the set of key-value pairs that are used to manage the resource | List | Connection |  |
Host |  |
RepositoryLink |  |
PassConnection [permission only] | Grants permission to pass a Connection resource to an AWS service that accepts a Connection ARN as input, such as codepipeline:CreatePipeline | Read | Connection* |  |
| codeconnections:PassedToService |
PassRepository [permission only] | Grants permission to pass a repository link resource to an AWS service that accepts a RepositoryLinkId as input, such as codeconnections:CreateSyncConfiguration | Read | RepositoryLink* |  |
| codeconnections:PassedToService |
RegisterAppCode [permission only] | Grants permission to associate a third party server, such as a GitHub Enterprise Server instance, with a Host | Read |  | codeconnections:HostArn |
StartAppRegistrationHandshake [permission only] | Grants permission to associate a third party server, such as a GitHub Enterprise Server instance, with a Host | Read |  | codeconnections:HostArn |
StartOAuthHandshake [permission only] | Grants permission to associate a third party, such as a Bitbucket App installation, with a Connection | Read |  | codeconnections:ProviderType |
TagResource | Grants permission to add or modify the tags of the given resource | Tagging | Connection |  |
Host |  |
RepositoryLink |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | Grants permission to remove tags from an AWS resource | Tagging | Connection |  |
Host |  |
RepositoryLink |  |
| aws:TagKeys |
UpdateConnectionInstallation | Grants permission to update a Connection resource with an installation of the CodeStar Connections App | Write | Connection* |  | codeconnections:GetIndividualAccessToken codeconnections:GetInstallationUrl codeconnections:ListInstallationTargets codeconnections:StartOAuthHandshake
| codeconnections:InstallationId |
UpdateHost | Grants permission to update a host resource | Write | Host* |  |
UpdateRepositoryLink | Grants permission to update a repository link | Write | RepositoryLink* |  |
UpdateSyncBlocker | Grants permission to update a sync blocker for a resource (cfn stack or other resources) | Write |  |  |
UpdateSyncConfiguration | Grants permission to update a sync configuration | Write |  | codeconnections:Branch |
UseConnection [permission only] | Grants permission to use a Connection resource to call provider actions | Read | Connection* |  |
| codeconnections:BranchName codeconnections:FullRepositoryId codeconnections:OwnerId codeconnections:ProviderAction codeconnections:ProviderPermissionsRequired codeconnections:RepositoryName |

## Resource types defined by AWS CodeConnections

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
Connection | `arn:$ { Partition}:codeconnections:$ { Region}:$ { Account}:connection/$ { ConnectionId}` | aws:ResourceTag/${TagKey}
Host | `arn:$ { Partition}:codeconnections:$ { Region}:$ { Account}:host/$ { HostId}` | aws:ResourceTag/${TagKey}
RepositoryLink | `arn:$ { Partition}:codeconnections:$ { Region}:$ { Account}:repository-link/$ { RepositoryLinkId}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS CodeConnections

AWS CodeConnections defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the tags that are passed in the request | String
aws:ResourceTag/${TagKey} | Filters access by the tags associated with the resource | String
aws:TagKeys | Filters access by the tag keys that are passed in the request | ArrayOfString
codeconnections:Branch | Filters access by the branch name that is passed in the request | String
codeconnections:BranchName | Filters access by the branch name that is passed in the request. Applies only to UseConnection requests for access to a specific repository branch | String
codeconnections:FullRepositoryId | Filters access by the repository that is passed in the request. Applies only to UseConnection requests for access to a specific repository | String
codeconnections:HostArn | Filters access by the host resource associated with the connection used in the request | ARN
codeconnections:InstallationId | Filters access by the third-party ID (such as the Bitbucket App installation ID for CodeConnections) that is used to update a Connection. Allows you to restrict which third-party App installations can be used to make a Connection | String
codeconnections:OwnerId | Filters access by the owner of the third-party repository. Applies only to UseConnection requests for access to repositories owned by a specific user | String
codeconnections:PassedToService | Filters access by the service to which the principal is allowed to pass a Connection or RepositoryLink | String
codeconnections:ProviderAction | Filters access by the provider action in a UseConnection request such as ListRepositories. See documentation for all valid values | ArrayOfString
codeconnections:ProviderPermissionsRequired | Filters access by the write permissions of a provider action in a UseConnection request. Valid types include read_only and read_write | String
codeconnections:ProviderType | Filters access by the type of third-party provider passed in the request | String
codeconnections:ProviderTypeFilter | Filters access by the type of third-party provider used to filter results | String
codeconnections:RepositoryName | Filters access by the repository name that is passed in the request. Applies only to UseConnection requests for access to repositories owned by a specific user | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.